Index: codecs/codec_g726.c
===================================================================
--- codecs/codec_g726.c	(revision 242606)
+++ codecs/codec_g726.c	(working copy)
@@ -770,6 +770,22 @@
 	return 0;
 }
 
+/*! \brief convert G726-32 RFC3551 packed data into AAL2 packed data (or vice-versa) */
+static int g726tog726aal2_framein(struct ast_trans_pvt *pvt, struct ast_frame *f)
+{
+	unsigned char *src = f->data.ptr;
+	unsigned char *dst = pvt->outbuf.uc + pvt->samples;
+	unsigned int i;
+
+	for (i = 0; i < f->datalen; i++)
+		*dst++ = ((src[i] & 0xf) << 4) | (src[i] >> 4);
+
+	pvt->samples += f->samples;
+	pvt->datalen += f->datalen;
+
+	return 0;
+}
+
 static struct ast_frame *g726tolin_sample(void)
 {
 	static struct ast_frame f = {
@@ -848,6 +864,26 @@
 	.buf_size = BUFFER_SAMPLES / 2,
 };
 
+static struct ast_translator g726tog726aal2 = {
+	.name = "g726tog726aal2",
+	.srcfmt = AST_FORMAT_G726,
+	.dstfmt = AST_FORMAT_G726_AAL2,
+	.framein = g726tog726aal2_framein,	/* same for both directions */
+	.sample = lintog726_sample,
+	.buffer_samples = BUFFER_SAMPLES,
+	.buf_size = BUFFER_SAMPLES,
+};
+
+static struct ast_translator g726aal2tog726 = {
+	.name = "g726aal2tog726",
+	.srcfmt = AST_FORMAT_G726_AAL2,
+	.dstfmt = AST_FORMAT_G726,
+	.framein = g726tog726aal2_framein,	/* same for both directions */
+	.sample = lintog726_sample,
+	.buffer_samples = BUFFER_SAMPLES,
+	.buf_size = BUFFER_SAMPLES,
+};
+
 static int parse_config(int reload)
 {
 	struct ast_variable *var;
@@ -860,7 +896,7 @@
 		return 0;
 	for (var = ast_variable_browse(cfg, "plc"); var; var = var->next) {
 		if (!strcasecmp(var->name, "genericplc")) {
-			g726tolin.useplc = ast_true(var->value) ? 1 : 0;
+			g726aal2tolin.useplc = g726tolin.useplc = ast_true(var->value) ? 1 : 0;
 			ast_verb(3, "codec_g726: %susing generic PLC\n",
 					g726tolin.useplc ? "" : "not ");
 		}
@@ -886,6 +922,9 @@
 	res |= ast_unregister_translator(&g726aal2tolin);
 	res |= ast_unregister_translator(&lintog726aal2);
 
+	res |= ast_unregister_translator(&g726aal2tog726);
+	res |= ast_unregister_translator(&g726tog726aal2);
+
 	return res;
 }
 
@@ -903,6 +942,9 @@
 	res |= ast_register_translator(&g726aal2tolin);
 	res |= ast_register_translator(&lintog726aal2);
 
+	res |= ast_register_translator(&g726aal2tog726);
+	res |= ast_register_translator(&g726tog726aal2);
+
 	if (res) {
 		unload_module();
 		return AST_MODULE_LOAD_FAILURE;
